@@ -107,7 +107,13 @@ test_matching_task_type = function(task_type, object, class) {
 #' @export
 #' @param learners (list of [Learner]).
 #' @rdname mlr_assertions
-assert_learners = function(learners, task = NULL, task_type = NULL, properties = character(), .var.name = vname(learners)) {
+assert_learners = function(learners, task = NULL, task_type = NULL, properties = character(), unique_ids = FALSE, .var.name = vname(learners)) {
+  if (unique_ids)  {
+    ids = map_chr(learners, "id")
+    if (!test_character(ids, unique = TRUE)) {
+      stopf("Learners need to have unique IDs: %s", str_collapse(ids))
+    }
+  }
   invisible(lapply(learners, assert_learner, task = task, task_type = NULL, properties = properties, .var.name = .var.name))
 }
 
@@ -200,6 +206,7 @@ assert_measure = function(measure, task = NULL, learner = NULL, prediction = NUL
   assert_class(measure, "Measure", .var.name = .var.name)
 
   if (!is.null(task)) {
+
     if (!is_scalar_na(measure$task_type) && !test_matching_task_type(task$task_type, measure, "measure")) {
       stopf("Measure '%s' is not compatible with type '%s' of task '%s'",
         measure$id, task$task_type, task$id)
@@ -215,6 +222,15 @@ assert_measure = function(measure, task = NULL, learner = NULL, prediction = NUL
   }
 
   if (!is.null(learner)) {
+
+    if ("requires_model" %in% measure$properties && is.null(learner$model)) {
+      stopf("Measure '%s' requires the trained model", measure$id)
+    }
+
+    if ("requires_model" %in% measure$properties && is_marshaled_model(learner$model)) {
+      stopf("Measure '%s' requires the trained model, but model is in marshaled form", measure$id)
+    }
+
     if (!is_scalar_na(measure$task_type) && measure$task_type != learner$task_type) {
       stopf("Measure '%s' is not compatible with type '%s' of learner '%s'",
         measure$id, learner$task_type, learner$id)
@@ -237,7 +253,7 @@ assert_measure = function(measure, task = NULL, learner = NULL, prediction = NUL
     }
   }
 
-  if (!is.null(prediction)) {
+  if (!is.null(prediction) && is.null(learner)) {
     # same as above but works without learner e.g. measure$score(prediction)
     if (measure$check_prerequisites != "ignore" && measure$predict_type %nin% prediction$predict_types) {
       warningf("Measure '%s' is missing predict type '%s' of prediction", measure$id, measure$predict_type)
