@@ -66,3 +66,19 @@ assert_validate = function(x) {
   }
   assert_choice(x, c("predefined", "test"), null.ok = TRUE)
 }
+
+get_obs_loss = function(tab, measures) {
+  for (measure in measures) {
+    fun = measure$obs_loss
+    value = if (is.function(fun)) {
+      args = intersect(names(tab), names(formals(fun)))
+      do.call(fun, tab[, args, with = FALSE])
+    } else {
+      NA_real_
+    }
+
+    set(tab, j = measure$id, value = value)
+  }
+
+  tab[]
+}
