@@ -44,25 +44,6 @@ test_that("Backends with different cols", {
   expect_data_table(b$data(rows = 1:120, cols = b$colnames), nrows = 120, ncols = 4)
 })
 
-test_that("Backends with mixed data_formats", {
-  requireNamespace("Matrix")
-  i = c(1, 3:8, 20)
-  j = c(2, 9, 6:10, 5)
-  x = 7 * (1:8)
-  A = Matrix::sparseMatrix(i, j, x = x)
-  colnames(A) = letters[1:10]
-  X = cbind(A, Y = rnorm(nrow(A)))
-  task = TaskRegr$new("sparse", X, "Y")
-
-  newdata = as.data.frame(as.list(set_names(rep(0, ncol(X)), colnames(X))))
-  task$rbind(newdata)
-  expect_backend(task$backend)
-  expect_set_equal(task$backend$data_formats, "data.table")
-
-  rr = resample(task, lrn("regr.rpart"), rsmp("holdout"))
-  expect_number(rr$aggregate(msr("regr.mse")))
-})
-
 test_that("Backends with same rows", {
   data = as.data.table(iris)
   data$id = 1:150
